@@ -39,8 +39,8 @@ class MonitorHandler(Thread):
     def _collect_per_path(self, paths: List[str]) -> Dict[str, Dict[str, Any]]:
         result = dict()
         for path in paths:
-            json, _ = get_json(path)['instances']
-            result.update(json)
+            json, _ = get_json(path)
+            result.update(json['instances'])
         return result
     
     def _save(self, old: dict, new: dict, name: str) -> None:
@@ -91,14 +91,11 @@ class MonitorHandler(Thread):
 
                     while not self._collector.stop_request:
                             
+                        if not self._collector.stop_request:
+                            self._collector.loop_barrier.wait()
+
                         self._collect(self.paths)
 
                         if self._collector.stop_request:
                             self._log.info('Releasing the barrier.')
                             self._collector.barrier.release()
-                        
-                        if not self._collector.stop_request:
-                            self._collector.loop_barrier.wait()
-                            
-
-
